<template>
  <a-card :bordered="false" title="排产工单">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="工单号(任务号)">
              <j-input placeholder="请输入工单号(任务号)" v-model="queryParam.workOrderCode"></j-input>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="物料编号">
              <j-input placeholder="请输入物料编号" v-model="queryParam.materialNumber"></j-input>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="工单状态">
              <j-dict-select-tag dictCode="work_order_status" placeholder="请输入工单状态"
                                 v-model="queryParam.workOrderStatus"></j-dict-select-tag>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="重发布人">
              <j-select-user-by-dep placeholder="请输入重发布人"
                                    v-model="queryParam.republisher"></j-select-user-by-dep>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="primary" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <a-spin :spinning="confirmLoading">
      <div>
        <a-table
          ref="table"
          size="middle"
          :scroll="{x:true}"
          bordered
          rowKey="id"
          :columns="columns"
          :dataSource="dataSource"
          :pagination="ipagination"
          :loading="loading"
          :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange,type: 'radio'}"
          class="j-table-force-nowrap"
          @change="handleTableChange">

          <template slot="htmlSlot" slot-scope="text">
            <div v-html="text"></div>
          </template>
          <template slot="imgSlot" slot-scope="text,record">
            <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
            <img v-else :src="getImgView(text)" :preview="record.id" height="25px" alt=""
                 style="max-width:80px;font-size: 12px;font-style: italic;" />
          </template>
          <template slot="fileSlot" slot-scope="text">
            <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
            <a-button
              v-else
              :ghost="true"
              type="primary"
              icon="download"
              size="small"
              @click="downloadFile(text)">
              下载
            </a-button>
          </template>

          <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>
        </a-table>
      </div>
      <a-tabs v-model="activeKey" @change="handleChangeTabs">
        <a-tab-pane tab="工单报工" :key="refKeys1[0]" :forceRender="true">
          <div style="display: flex; align-items: center; margin-bottom: 10px;">
          </div>
          <j-vxe-table
            keep-source
            :ref="refKeys1[0]"
            :loading="mesWorkReporting.loading"
            :columns="mesWorkReporting.columns"
            :dataSource="mesWorkReporting.dataSource"
            :maxHeight="300"
            :rowNumber="true"
            :rowSelection="true"
            :toolbar="false">
            <template slot="showDetail" slot-scope="{row}">
              <a-button type="primary" @click="handleOrderDetail(row)" size="small">
                <a-icon type="eye" />订单详情
              </a-button>
            </template>
          </j-vxe-table>
        </a-tab-pane>
        <a-tab-pane tab="物料拉动申请" :key="refKeys2[0]" :forceRender="true">
          <div style="display: flex; align-items: center; margin-bottom: 10px;">
          </div>
          <j-vxe-table
            keep-source
            :ref="refKeys2[0]"
            :loading="mesMaterialTransferRequest.loading"
            :columns="mesMaterialTransferRequest.columns"
            :dataSource="mesMaterialTransferRequest.dataSource"
            :maxHeight="300"
            :rowNumber="true"
            :rowSelection="true"
            :toolbar="false">
            <template slot="showTransferDetail" slot-scope="{row}">
              <a-button type="primary" @click="handleTransferDetail(row)" size="small">
                <a-icon type="eye" />物料拉动明细
              </a-button>
            </template>
          </j-vxe-table>
        </a-tab-pane>
        <a-tab-pane tab="上下料查询" :key="refKeys3[0]" :forceRender="true">
          <div style="display: flex; align-items: center; margin-bottom: 10px;">
          </div>
          <j-vxe-table
            keep-source
            :ref="refKeys3[0]"
            :loading="mesMaterialLoading.loading"
            :columns="mesMaterialLoading.columns"
            :dataSource="mesMaterialLoading.dataSource"
            :maxHeight="300"
            :rowNumber="true"
            :rowSelection="true"
            :toolbar="false">
            <template slot="showUnloadingDetail" slot-scope="{row}">
              <a-button type="primary" @click="handleUnLoadingDetail(row)" size="small">
                <a-icon type="eye" />下料详情
              </a-button>
            </template>
          </j-vxe-table>
        </a-tab-pane>
        <a-tab-pane tab="齐套性检查记录" :key="refKeys4[0]" :forceRender="true">
          <div style="display: flex; align-items: center; margin-bottom: 10px;">
          </div>
          <j-vxe-table
            keep-source
            :ref="refKeys4[0]"
            :loading="mesKittingCompletenessCheck.loading"
            :columns="mesKittingCompletenessCheck.columns"
            :dataSource="mesKittingCompletenessCheck.dataSource"
            :maxHeight="300"
            :rowNumber="true"
            :rowSelection="true"
            :toolbar="false"
          />
        </a-tab-pane>
      </a-tabs>
    </a-spin>
    <mes-production-work-order-modal ref="modalForm" @ok="modalFormOk"></mes-production-work-order-modal>
    <mes-production-order-modal ref="MesProductionOrderModal"></mes-production-order-modal>
    <MesMaterialUnloadingList ref="MesMaterialUnloadingList"></MesMaterialUnloadingList>
    <MesMaterialTransferDetailList ref="MesMaterialTransferDetailList"></MesMaterialTransferDetailList>
  </a-card>
</template>

<script>

import '@/assets/less/TableExpand.less'
import { mixinDevice } from '@/utils/mixin'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import MesProductionWorkOrderModal from './modules/MesProductionWorkOrderModal'
import { JVxeTableModelMixin } from '@/mixins/JVxeTableModelMixin.js'
import { JVXETypes } from '@/components/jeecg/JVxeTable'
import { filterMultiDictText } from '@/components/dict/JDictSelectUtil'
import { getAction } from '@api/manage'
import MesProductionOrderModal from '@views/mes/modules/MesProductionOrderModal.vue'
import MesMaterialUnloadingList from '@views/mes/MesMaterialUnloadingList.vue'
import MesMaterialTransferDetailList from '@views/mes/MesMaterialTransferDetailList.vue'

export default {
  name: 'MesProductionWorkOrderList',
  mixins: [JeecgListMixin, mixinDevice, JVxeTableModelMixin, JVXETypes],
  components: {
    MesProductionWorkOrderModal,
    MesProductionOrderModal,
    MesMaterialUnloadingList,
    MesMaterialTransferDetailList
  },
  data() {
    return {
      description: '排产工单管理页面',
      activeKey : 'mesWorkReporting',
      // 工单报工
      refKeys1: ['mesWorkReporting'],
      tableKeys1: ['mesWorkReporting'],
      //物料拉动申请
      refKeys2: ['mesMaterialTransferRequest'],
      tableKeys2: ['mesMaterialTransferRequest'],
      //上料
      refKeys3: ['mesMaterialLoading'],
      tableKeys3: ['mesMaterialLoading'],
      //齐套性检查记录
      refKeys4: ['mesKittingCompletenessCheck'],
      tableKeys4: ['mesKittingCompletenessCheck'],
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '工单号(任务号)',
          align: 'center',
          dataIndex: 'workOrderCode'
        },
        {
          title: '物料编码',
          align: 'center',
          dataIndex: 'materialNumber'
        },
        {
          title: '物料名称',
          align: 'center',
          dataIndex: 'materialName'
        },
        {
          title: '计划生产数量',
          align: 'center',
          dataIndex: 'planQuantity'
        },
        {
          title: '产线(冗余)',
          align: 'center',
          dataIndex: 'factoryId_dictText'
        },
        {
          title: '班组',
          align: 'center',
          dataIndex: 'groupId_dictText'
        },
        {
          title: '班次(冗余)',
          align: 'center',
          dataIndex: 'shiftId_dictText'
        },
        {
          title: '排产日期',
          align: 'center',
          dataIndex: 'workOrderDate'
        },
        {
          title: '工单状态',
          align: 'center',
          dataIndex: 'workOrderStatus_dictText'
        },
        {
          title: '实际报工数量',
          align: 'center',
          dataIndex: 'actualQuantity'
        },
        {
          title: '发布人',
          align: 'center',
          dataIndex: 'publisher'
        },
        {
          title: '发布时间',
          align: 'center',
          dataIndex: 'publishTime'
        },
        {
          title: '重发布人',
          align: 'center',
          dataIndex: 'republisher'
        },
        {
          title: '重发布时间',
          align: 'center',
          dataIndex: 'republishTime'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      mesWorkReporting: {
        loading: false,
        dataSource: [],
        columns: [
          {
            title: '操作',
            key: 'action',
            type: JVXETypes.slot,
            slotName: 'showDetail',
            width: '120px',
            align: 'center'
          },
          {
            title: '订单号',
            key: 'orderCode',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '工单号',
            key: 'workOrderCode',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '产线名称',
            key: 'factoryName',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '批次号',
            key: 'batchNumber',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '托号',
            key: 'palletNumber',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '数量',
            key: 'quantity',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '报工人',
            key: 'reporter',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '报工时间',
            key: 'reportTime',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '线边仓名称',
            key: 'warehouseName',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '成品下线打印状态',
            key: 'printStatus',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
        ]
      },
      mesMaterialTransferRequest: {
        loading: false,
        dataSource: [],
        columns: [
          {
            title: '操作',
            key: 'action',
            type: JVXETypes.slot,
            slotName: 'showTransferDetail',
            width: '120px',
            align: 'center'
          },
          {
            title: '拉动单号',
            key: 'requestCode',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '工单号',
            key: 'workOrderCode',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: 'SAP预留号',
            key: 'reservationCode',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '发布状态',
            key: 'publishStatus',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '请求状态',
            key: 'requestStatus',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '请求时间',
            key: 'requestTime',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '原库存地',
            key: 'originalWarehouseName',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '目标库存地',
            key: 'targetWarehouseName',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '优先级',
            key: 'priority',
            type: JVXETypes.select,
            dictCode: 'priority',
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '最晚配送时间',
            key: 'latestDeliveryTime',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
        ]
      },
      mesMaterialLoading: {
        loading: false,
        dataSource: [],
        columns: [
          {
            title: '操作',
            key: 'action',
            type: JVXETypes.slot,
            slotName: 'showUnloadingDetail',
            width: '120px',
            align: 'center'
          },
          {
            title: '工单号',
            key: 'workOrderCode',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '设备ID',
            key: 'equipmentId',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '工序编码',
            key: 'processCode',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '工序名称',
            key: 'processName',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '物料编码',
            key: 'materialNumber',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '物料名称',
            key: 'materialName',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '批次号',
            key: 'batchNumber',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '数量',
            key: 'quantity',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '剩余数量',
            key: 'remainingQuantity',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
        ]
      },
      mesKittingCompletenessCheck: {
        loading: false,
        dataSource: [],
        columns: [
          {
            title: '工单号',
            key: 'workOrderCode',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '物料编号',
            key: 'materialNumber',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '物料名称',
            key: 'materialName',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '需求数量',
            key: 'requiredQuantity',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '实际数量',
            key: 'actualQuantity',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
          {
            title: '是否齐备',
            key: 'checkFlag',
            type: JVXETypes.input,
            width: '200px',
            placeholder: '请输入${title}',
            defaultValue: ''
          },
        ]
      },
      url: {
        list: '/mesproductionworkorder/mesProductionWorkOrder/list',
        delete: '/mesproductionworkorder/mesProductionWorkOrder/delete',
        deleteBatch: '/mesproductionworkorder/mesProductionWorkOrder/deleteBatch',
        exportXlsUrl: '/mesproductionworkorder/mesProductionWorkOrder/exportXls',
        importExcelUrl: 'mesproductionworkorder/mesProductionWorkOrder/importExcel',
        queryWorkReportingByWorkOrderId:'/mesworkreporting/mesWorkReporting/queryWorkReportingByWorkOrderId',
        queryMaterialTransferRequestByWorkOrderId:'/mesmaterialtransferrequest/mesMaterialTransferRequest/queryMaterialTransferRequestByWorkOrderId',
        queryLoadingByWorkOrderId:'/mes/mesMaterialLoading/queryLoadingByWorkOrderId',
        queryCompletenessCheckByWorkOrderId:'/meskittingcompletenesscheck/mesKittingCompletenessCheck/queryCompletenessCheckByWorkOrderId',
        queryOrderById:'/mesproductionwork/mesProductionOrder/queryById',
        queryUnloadingByLoadingId:'/mes/mesMaterialUnloading/queryUnloadingByLoadingId',
        queryTransferDetailBy:'/mes/mesMaterialTransferDetail/queryTransferDetailBy'
      },
      dictOptions: {},
      superFieldList: []
    }
  },
  created() {
    this.getSuperFieldList()
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  methods: {
    async handleTransferDetail(row){
      console.log('row---->',row)
      const transferDetailResult = await getAction(this.url.queryTransferDetailBy,{'requestId':row.id})
      this.$refs.MesMaterialTransferDetailList.visible = true
      this.$refs.MesMaterialTransferDetailList.dataSource = transferDetailResult.result.records
    },
    async handleUnLoadingDetail(row){
      console.log('row---->',row)
      const unloadingResult = await getAction(this.url.queryUnloadingByLoadingId,{'loadingId':row.id})
      this.$refs.MesMaterialUnloadingList.visible = true
      this.$refs.MesMaterialUnloadingList.dataSource = unloadingResult.result.records
    },
    async handleOrderDetail(row){
      const orderResult = await getAction(this.url.queryOrderById,{'id':row.orderId})
      this.$refs.MesProductionOrderModal.edit(orderResult.result)
      this.$refs.MesProductionOrderModal.title="订单详情";
      this.$refs.MesProductionOrderModal.disableSubmit = true;
    },
    async onSelectChange(selectedRowKeys){
      //mesWorkReporting,mesMaterialTransferRequest,mesMaterialLoading,mesKittingCompletenessCheck
      this.mesWorkReporting.loading = true
      this.mesMaterialTransferRequest.loading = true
      this.mesMaterialLoading.loading = true
      this.mesKittingCompletenessCheck.loading = true

      this.selectedRowKeys = selectedRowKeys
      this.mesWorkReporting.dataSource=[]
      this.mesMaterialTransferRequest.dataSource=[]
      this.mesMaterialLoading.dataSource=[]
      this.mesKittingCompletenessCheck.dataSource=[]
      if (selectedRowKeys.length > 0) {
        const selectedId = selectedRowKeys[0] // 选中行的id
        let parm = {
          'workOrderId':selectedId
        }
        const mesWorkReportingResult = await getAction(this.url.queryWorkReportingByWorkOrderId, parm)
        const mesMaterialTransferRequestResult = await getAction(this.url.queryMaterialTransferRequestByWorkOrderId, parm)
        const mesMaterialLoadingResult = await getAction(this.url.queryLoadingByWorkOrderId, parm)
        const mesKittingCompletenessCheckResult = await getAction(this.url.queryCompletenessCheckByWorkOrderId, parm)
        this.mesWorkReporting.dataSource = mesWorkReportingResult.result
        this.mesMaterialTransferRequest.dataSource = mesMaterialTransferRequestResult.result
        this.mesMaterialLoading.dataSource = mesMaterialLoadingResult.result
        this.mesKittingCompletenessCheck.dataSource = mesKittingCompletenessCheckResult.result
        this.mesWorkReporting.loading = false
        this.mesMaterialTransferRequest.loading = false
        this.mesMaterialLoading.loading = false
        this.mesKittingCompletenessCheck.loading = false
      }
    },
    initDictConfig() {
    },
    getSuperFieldList() {
      let fieldList = []
      fieldList.push({ type: 'int', value: 'delFlag', text: '删除标记', dictCode: '' })
      fieldList.push({ type: 'string', value: 'workOrderCode', text: '工单号(任务号)', dictCode: '' })
      fieldList.push({ type: 'string', value: 'materialNumber', text: '物料编码', dictCode: '' })
      fieldList.push({ type: 'string', value: 'materialName', text: '物料名称', dictCode: '' })
      fieldList.push({ type: 'double', value: 'planQuantity', text: '计划生产数量', dictCode: '' })
      fieldList.push({ type: 'string', value: 'factoryId', text: '产线ID(冗余)', dictCode: '' })
      fieldList.push({ type: 'string', value: 'groupId', text: '班组ID', dictCode: '' })
      fieldList.push({ type: 'string', value: 'shiftId', text: '班次ID(冗余)', dictCode: '' })
      fieldList.push({ type: 'datetime', value: 'workOrderDate', text: '排产日期' })
      fieldList.push({ type: 'string', value: 'workOrderStatus', text: '工单状态', dictCode: 'work_order_status' })
      fieldList.push({ type: 'double', value: 'actualQuantity', text: '实际报工数量', dictCode: '' })
      fieldList.push({ type: 'string', value: 'publisher', text: '发布人', dictCode: '' })
      fieldList.push({ type: 'datetime', value: 'publishTime', text: '发布时间' })
      fieldList.push({ type: 'string', value: 'republisher', text: '重发布人', dictCode: '' })
      fieldList.push({ type: 'datetime', value: 'republishTime', text: '重发布时间' })
      this.superFieldList = fieldList
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>